/**
 *  UOC Hive Campus per UOC OPEN API
 *  <br />
 *  
 *
 *  @author Ral Martnez Daz
 *  @version 1.0
 */

package com.uoc.hive.campus;



import com.uoc.hive.campus.model.EventList;


import android.os.AsyncTask;
import android.os.Bundle;
import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;

import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;

import android.widget.ListView;

import android.widget.TextView;
import android.widget.Toast;


// TODO - Mostrar events per dies / setmanes / mesos
// 		  Ara per ara UOC OPEN API noms mostra n events tots amb el mateix id i data.

// TODO - Mostra detall de event en finestra

/**
 * Representa el Calendari d'un usuari. <br>
 * Mostra un llistat d'events. * 
 * @pre Disposem d'un token vlid. <br><br>
 */
public class CalendarActivity extends Activity {

	private Activity a;
	private String token;
	private EventList events;
	
	private ProgressDialog dialog;
	
	private listEventAdapter adapter;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_calendar);
		
		a = this;
		
		// Verifiquem que tenim el token
		token = Utilities.getToken(); 
		if (token.contentEquals("error")) {
			finish();
		}
		
		// Modifiquem titol
		TextView label = (TextView) findViewById(R.id.titleBarText);
		label.setText(R.string.title_activity_calendar);
		
		// Creem barra de progress per mostrar mentre es carrega el llistat d'aules.
		dialog = new ProgressDialog (a);
		
		addListenerOnButtons();
	}

	@Override
	protected void onResume() {
		super.onResume();
		
		// Recuperem llistat d'events de l'usuari
		new LoadEventListTask().execute();
		
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.message, menu);
		return true;
	}
	@Override
	public boolean onContextItemSelected(MenuItem item){
		switch(item.getItemId()){
			case R.id.menu_settings:
				finish();
				return true;
			default:
				return super.onContextItemSelected(item);			
		}
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item){
		switch(item.getItemId()){
			case R.id.menu_close:
				finish();
				return true;
			case R.id.menu_settings:
					Intent i = new Intent(CalendarActivity.this, TaulellActivity.class);
					startActivity(i.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP));
				return true;	
			default:
				return super.onContextItemSelected(item);			
		}
	}
	
	 /**
     * Recupera el llistat d'events d'un usuari. Tasca asyncrona. 
	 * 	 
	 * @pre Disposem d'un token vlid. 		
	 * @post S'ha recuperat el llistat d'events i es mostren al desplegable.
	 */
	 private class LoadEventListTask extends AsyncTask<String, Void, Boolean> {
				
		protected void onPostExecute(Boolean result) {
			
			if (result == true) {	
				
				// Tanquem finestra de progress
				if (dialog.isShowing()){
					dialog.dismiss();
				}
				
				Log.i("iEVENTLIST", "S'ha carregat conjunt d'events");
			
							
				// Afegim el llistat d'events al desplegable.
				ListView list=(ListView)findViewById(R.id.eventList);				
				
				// TODO - utilitzar diferents Adapters en funci de vista dia /setmana / mes  
				try { 
					
					adapter=new listEventAdapter(a, events);
					list.setAdapter(adapter);
				} catch (Exception ex) {
					Toast.makeText(getApplicationContext(),
							ex.getMessage(), Toast.LENGTH_LONG).show();
				}
					
				
			} else {
				// S'ha produt algun error en la recuperaci de les dades. Ho notifiquem a l'usuari.
				
				// Tanquem finestra de progrs
				if (dialog.isShowing()){
					dialog.dismiss();
				}
				Toast.makeText(getApplicationContext(),
						"No s'han pogut recuperar events", Toast.LENGTH_LONG).show();				
			}
		 }
		
		 @Override
		 protected void onPreExecute() {			
		 	super.onPreExecute();
		 	
		 	// Obrim finestra de progrs
		 	dialog.setMessage("Carregant events...");
		 	dialog.show();
		 }

		 protected Boolean doInBackground(String... params) {			
						
			// TODO - Recuperar events per dia / setmana / mes 
			
			// Recuperem llistat de carpetes de la bstia/board
			events = EventList.getEvents(token);
			
			if (events != null) return true;			
			return false;
		 }
	 }
		
	
	/**
     * Conjunt de disparadors de l'Activity.    
	 */	
	public void addListenerOnButtons() {	
			
		/**
	     * Bot tancar de la barra de men - Finalitza l'Activity.    
		 */
		findViewById(R.id.titleBarButton).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				finish();
			}		 
		});
		
		
		/**
	     * Bot refresta de la barra al peu - Recarrega l'Activity.    
		 */
		findViewById(R.id.footerBarRefresh).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				finish();				
				startActivity(getIntent());
			}		 
		});
	}
	
	
	

}
