/**
 *  UOC Hive Campus per UOC OPEN API
 *  <br />
 *  
 *
 *  @author Ral Martnez Daz
 *  @version 1.0
 */

package com.uoc.hive.campus;




import com.uoc.hive.campus.model.BoardList;
import com.uoc.hive.campus.model.ClassRoom;


import android.os.AsyncTask;
import android.os.Bundle;
import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

public class ClassRoomActivity extends Activity {	
	private String token, classroom_id;
	
	private ClassRoom classRoom;
	private BoardList boards;
	
	private Activity a;
	
	private listBoardAdapter adapter;
	private ProgressDialog dialog;
	

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_classroom);
		
		a = this;
		// Verifiquem que tenim el token
		token = Utilities.getToken(); 
		if (token.contentEquals("error")) {
				finish();
		}			
		
		// Modifiquem titol
		TextView label = (TextView) findViewById(R.id.titleBarText);
		label.setText(R.string.title_activity_class_room);
		
		
		
		// Recuperem 
		Bundle extras = getIntent().getExtras();
		if (extras != null) {				
				this.classroom_id = extras.getString("URI");
		} else {
				Toast.makeText(this, "Error de Intent", Toast.LENGTH_LONG).show();
				finish();
		}
		
		// Mostrem barra de progress mentre es carrega el llistat de recursos.
	    dialog = new ProgressDialog (a);
	    
	    // TODO - Carregar events del calendari vinculats a l'aula.
	    //		  Opci encara no incorporada a [ UOC OPEN API ]
	    
	    // TODO - Afegir accs a material de l'aula ( fora objectiu  projecte )
	    // TODO - Afegir accs a resources de l'aula ( fora objectiu projecte )
	    // TODO - Veure companys de l'aula ( fora objectiu projecte )
		
		addListenerOnButtons();	
		
	}
	
	@Override
	protected void onResume () {
		super.onResume ();
		 
		// Verifiquem que tenim el token
		token = Utilities.getToken(); 
		if (token.contentEquals("error")) {
				finish();
		}	
		
		Log.i("iCLASSROOM", "S'ha carregat un aula");
			
		new LoadClassroomTask().execute(classroom_id);
		new LoadBoardsTask().execute(classroom_id);	
		
	}
	
	

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.message, menu);
		return true;
	}
	@Override
	public boolean onOptionsItemSelected(MenuItem item){
		switch(item.getItemId()){
			case R.id.menu_close:
				finish();
				return true;
			case R.id.menu_settings:
					Intent i = new Intent(ClassRoomActivity.this, TaulellActivity.class);
					startActivity(i.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP));
				return true;	
			default:
				return super.onContextItemSelected(item);			
		}
	}
	
	/**
     * Recupera les dades d'un aula. Tasca asyncrona. 
	 * 	
	 * @pre Disposem d'un token vlid. 		
	 * @post S'han recuperat les dades de l'aula i es mostren.
	 */
	 private class LoadClassroomTask extends AsyncTask<String, Void, Boolean> {
				
		protected void onPostExecute(Boolean result) {
			
			
			// Tanquem finestra de progress
			if (dialog.isShowing()){
				dialog.dismiss();
			}
			
			if (result == true) {	
				
				TextView aulaTitle= (TextView) findViewById(R.id.aulaTitle);
				
				// Modifica el titol i el color de l'aula
				aulaTitle.setText(Utilities.cutString(50, classRoom.getTitle()));
				aulaTitle.setBackgroundColor(Utilities.parseColor(classRoom.getColor()));
								
				Log.i("iCLASSROOM", "S'han carregat les dades de l'aula");
				
				
			} else {
				// S'ha produt algun error en la recuperaci de les dades. Ho notifiquem a l'usuari.
				Toast.makeText(getApplicationContext(),
						"No s'han pogut recuperar dades de l'aula", Toast.LENGTH_LONG).show();				
			}
		 }
		
		 @Override
		 protected void onPreExecute() {			
		 	super.onPreExecute();
		 	
		 	// Obrim finestra de progress
		 	dialog.setMessage("Carregant dades de l'aula...");
		 	dialog.show();
		 }

		 protected Boolean doInBackground(String... params) {	
			 
			// Recuperem llistat de recursos de conversa de l'aula.
			classRoom = ClassRoom.getClassRoom(params[0], token);
			
			if (classRoom != null)	return true;
					
			return false;
		 }
	 }
	 
	
	 /**
     * Recupera el llistat de recursos d'un aula. Tasca asyncrona. 
	 * 	
	 * @pre Disposem d'un token vlid. 		
	 * @post S'ha recuperat el llistat de recursos d'aula i es mostren.
	 */
	 private class LoadBoardsTask extends AsyncTask<String, Void, Boolean> {
				
		protected void onPostExecute(Boolean result) {
			ListView list;
			
			// Tanquem finestra de progress
			if (dialog.isShowing()){
				dialog.dismiss();
			}
			
			if (result == true) {				
				
				Log.i("iCLASSROOM", "S'han carregat els boards de l'aula");
				
				list = (ListView) findViewById(R.id.classroomBoardList);				
				try { 
					// Creem el llistat d'aules amb les dades recuperades.
					adapter=new listBoardAdapter(a, boards);
					list.setAdapter(adapter);
					
				} catch (Exception ex) {
					Toast.makeText(getApplicationContext(),
							ex.getMessage(), Toast.LENGTH_LONG).show();
				}
				
			} else {
				// S'ha produt algun error en la recuperaci de les dades. Ho notifiquem a l'usuari.
				Toast.makeText(getApplicationContext(),
						"No s'han pogut recuperar aules", Toast.LENGTH_LONG).show();				
			}
		 }
		
		 @Override
		 protected void onPreExecute() {			
		 	super.onPreExecute();
		 	
		 	// Obrim finestra de progress
		 	dialog.setMessage("Carregant llistat recursos...");
		 	dialog.show();
		 }

		 protected Boolean doInBackground(String... params) {	
			 
			// Recuperem llistat de recursos de conversa de l'aula.
			boards = BoardList.getBoardListRequest(params[0], token);
			
			if (boards != null)	return true;
					
			return false;
		 }
	 }
	 
	
	
	/**
     * Conjunt de disparadors de la Activity.    
	 */	
	public void addListenerOnButtons() {	
			
		/**
	     * Bot tancar de la barra de men - Finalitza l'activity.    
		 */
		findViewById(R.id.titleBarButton).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				finish();
			}		 
		});
		
		/**
	     * Bot refresta de la barra al peu - Recarrega l'activity.    
		 */
		findViewById(R.id.footerBarRefresh).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				
			}		 
		});
		
		/**
	     * Al prmer sobre un recurs obre finestra missatges.    
		 */
		ListView list=(ListView)findViewById(R.id.classroomBoardList);
		list.setOnItemClickListener(new AdapterView.OnItemClickListener() {
		    public void onItemClick(AdapterView<?> parent, View view, int pos, long id) {
		    	String board_id;
		    	String domain_id;
		    	
		    	domain_id = classroom_id;
		    	
		    	board_id = "classrooms/" + domain_id+ "/boards/";
		    	
		    	board_id = board_id + boards.getBoardList().get(pos).getId()+"/";
		    	
		    	Log.i("iCLASSROOM", "Carregant "+board_id);
		    	
		    	Intent i = new Intent(ClassRoomActivity.this, InboxActivity.class);	    					
	    		i.putExtra("URI",board_id);	
	    		i.putExtra("context", classRoom.getTitle());
	    		startActivity(i); 		    	
		    }
		});
	}

}
