/**
 *  UOC Hive Campus per UOC OPEN API
 *  <br />
 *  
 *
 *  @author Ral Martnez Daz
 *  @version 1.0
 */

package com.uoc.hive.campus;

import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Bundle;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.TextView;

/**
 * Finestra inicial de l'aplicaci, gestiona l'identifiaci de l'usuari. <br>
 * Llena el navegador web per a l'identificaci OAuth de l'usuari al Campus Virtual, 
 * obtenint el token  d'autoritzaci. 
 */

public class HiveCampusActivity extends Activity {
	
	private Activity a;
	public boolean running;	
	
	private boolean isLogged = false;	
	private boolean retry = false;
	private boolean back = false;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
				
		this.isLogged = false;
		a = this;	
		
		Log.i("iHIVE", "Iniciant aplicaci Hive Campus.");
		
		addListenerOnButtons();		
	}
	
	@Override
	protected void onResume() {
		super.onResume();		
		
		// Comprova si el dispositiu t connexi a Internet.
		// Si no hi ha connexi no permet continuar.
		if (isOnline() == false){
			TextView text = (TextView)findViewById(R.id.text_errorPanel);
			text.setText("Dispositiu sense connexi !!!");
			
			text = (TextView)findViewById(R.id.ButtonTaulell_errorPanel);
			text.setVisibility(TextView.INVISIBLE);
		} else {
		
				
			// Si est logat i l'usuari torna del taulell, mostrar missatge confirmaci sortir.
			if ((this.isLogged == true) && (this.back == true)){
				TextView text = (TextView)findViewById(R.id.text_errorPanel);
				text.setText(" Segur que vols sortir ?");
									
				text = (TextView)findViewById(R.id.ButtonTaulell_errorPanel);
				text.setText("Taulell");
				text.setCompoundDrawablesWithIntrinsicBounds(R.drawable.ic_taulell, 0, 0, 0);
			}
		
			// 	Si est logat i no torna del taulell obrir el taulell
			if ((this.isLogged == true) && (this.back == false)){
				back = true;
				Intent i = new Intent(HiveCampusActivity.this, TaulellActivity.class);	
				startActivity(i);
			}
				
			// 	Si no est logat ni s'ha produt un error de validaci, llena finestra de validaci.
			if ( (this.isLogged == false) && (this.retry == false)) {			
				Log.i("iHIVE", "Cridant finestra login");
				Intent i = new Intent(a, logonUOCActivity.class);	
				startActivityForResult(i,0);				
			} 
		
			// Si no est logat, i s'ha produt un error de validaci.
			if ( (this.isLogged == false) && (this.retry == true)) {
				TextView text = (TextView)findViewById(R.id.text_errorPanel);
				text.setText("Usuari no identificat !!!");
						
				text = (TextView)findViewById(R.id.ButtonTaulell_errorPanel);
				text.setText("Validar usuari");
				text.setCompoundDrawablesWithIntrinsicBounds(R.drawable.ic_reload, 0, 0, 0);
			}
		}		
	}
	
	
	/**
     * Recupera el resultat d'una crida startActivityForResult. 
     * Comprova que l'identificaci s'ha completat i tenim un token vlid.   
     * 
	 * @pre S'ha cridat una Activity i s'espera un resultat. 		
	 * @post S'ha retornat de la crida i tenim un Intent amb el resultat de l'Activity
	 */
	@Override 
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode,  resultCode,  data);
		if (requestCode == 0) {
			Log.i("iHIVE", "Torna de finestra login");
		
			if (resultCode == RESULT_OK){
				
				// Hem recuperat el token correctament i l'usuari est validat
				Log.i("iHIVE", "Recupera token");				
				this.isLogged = true;
			}	
			
			if (resultCode == RESULT_CANCELED) {
				retry = true;
				
				// No hem recuperat el token correctament, mostrar bot Retry
				TextView text = (TextView)findViewById(R.id.text_errorPanel);
				text.setText("Error en procs validaci");
				
				Log.i("iHIVE", "Result cancelado");
			}
		}
	}

	 
	
	/**
     * Comprova si el dispositiu disposa de connexi a Internet
     * @return TRUE - si el dispositiu disposa de connexi a Internet<br>
     *		   FALSE -si no disposem de connexi.
     */
	public boolean isOnline() {
	    ConnectivityManager cm =
	        (ConnectivityManager) getSystemService(Context.CONNECTIVITY_SERVICE);
	    NetworkInfo netInfo = cm.getActiveNetworkInfo();
	    if (netInfo != null && netInfo.isConnected()) {
	        return true;
	    }
	    return false;
	}
	
	/**
     * Conjunt de disparadors de la Activity.    
	 */
	public void addListenerOnButtons() {			
						
		/**
	     * Bot tancar - Finalitza l'activity.    
		 */
		findViewById(R.id.ButtonClose_errorPanel).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				finish();
			}		 
		});
		
		/**
	     * Bot taulell o validar - Si l'usuari est validat accedeix al taulell, si no obre 
	     * finestra de validaci.   
		 */
		findViewById(R.id.ButtonTaulell_errorPanel).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				
				// Si est logat obrir taulell.
				if (isLogged == true){
					Intent i = new Intent(a, TaulellActivity.class);	
					startActivity(i);
				}
				
				// Si no est logat obrir finestra de validaci.
				if (isLogged == false) {
					Intent i = new Intent(a, logonUOCActivity.class);	
					startActivityForResult(i,0);
				}
				
				
			}		 
		});
	}
	
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.logon_menu, menu);
		return true;
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item){
		switch(item.getItemId()){
			case R.id.menu_close:
				finish();
				return true;				
			default:
				return super.onContextItemSelected(item);			
		}
	}

}
