/**
 *  UOC Hive Campus per UOC OPEN API
 *  <br />
 *  
 *
 *  @author Ral Martnez Daz
 *  @version 1.0
 */

package com.uoc.hive.campus;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;


import com.uoc.hive.campus.model.Folder;
import com.uoc.hive.campus.model.FolderList;
import com.uoc.hive.campus.model.MessageList;

import android.os.AsyncTask;
import android.os.Bundle;
import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;

import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.RelativeLayout;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;


/**
 * Representa una bstia de missatges del Campus Virtual. <br>
 * Por utilitzar-se, tant per mostrar la bstia de correu d'un usuari,
 * com per mostar els missatges d'un recurs de conversa dins d'un aula.
 * @pre Disposem d'un token vlid. <br><br>
 * 		Hem emmagatzemant el context de la bstia de missagtes a l'intent que realitza la crida.  <br>
 *      - Exemple bstia de correu:    "mail"<br>
 *      - Exemple recurs de conversa:  "classroom/{domain_id}/boards/{board_id}"
 */

public class InboxActivity extends Activity {
	
	private String token, contxt;
	private Activity a;
	
	private ListView list;
	private mailAdapter adapter;
	
	
	private Folder folder;
	private MessageList messages;	
	private FolderList folderlist;
	
	private String baseURI = "mail/";	
	
	private Long unreadMessages, totalMessages;
	
	private ProgressDialog dialog;
	

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_inbox);
		
		a = this;
		
		// Recuperem el token
		token = Utilities.getToken(); 
		if (token.contentEquals("error")) {
				finish();
		}
				
		// Modifiquem titol
		TextView label = (TextView) findViewById(R.id.titleBarText);
		label.setText(R.string.title_activity_inbox);
				
		// Recuperem URI i el context ( bstia o recurs de conversa )
		Bundle extras = getIntent().getExtras();
		if (extras != null) {		    	
		    this.baseURI = extras.getString("URI");	
		    this.contxt = extras.getString("context");
		} else {
				Toast.makeText(this, "Error de intent", Toast.LENGTH_LONG).show();
				finish();
		}
		
		// Si es un recurs de conversa, mostrem l'aula que cont el recurs de conversa.
		if (baseURI.contains("classrooms")) {
			
			RelativeLayout layout = (RelativeLayout) findViewById(R.id.aula_layout);
			layout.setVisibility(View.VISIBLE);
			
			label = (TextView) findViewById(R.id.textTitle);
			label.setText(contxt);
		}
		
		// Creem barra de progress per mostrar mentre es carrega el llistat d'aules.
		dialog = new ProgressDialog (a);
				
				
		// Recuperem les carpetes de la bstia.
		// TODO - Moure-ho al mtode onResume, perque recarregui les dades cada vegada de tornem.
		
		Log.i("iMESSAGELIST", "S'ha accedit a llistat de missatges");
		
		new LoadMailFolderListTask().execute(baseURI);	
						
		// Incorporem els disparadors
		addListenerOnButtons();
	}
	
	@Override
	protected void onResume () {
		super.onResume();
		// Verifiquem que tenim el token
		token = Utilities.getToken(); 
		if (token.contentEquals("error")) {
			finish();
		}
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.		
		getMenuInflater().inflate(R.menu.message, menu);
		return true;
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item){
		switch(item.getItemId()){
			case R.id.menu_close:
				finish();
				return true;
			case R.id.menu_settings:
					Intent i = new Intent(InboxActivity.this, TaulellActivity.class);
					startActivity(i.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP));
				return true;	
			default:
				return super.onContextItemSelected(item);			
		}
	}
		
	 
	
	 /**
     * Recupera el llistat de carpetes d'un recurs. Tasca asyncrona. 
	 * 
	 * @param String URI del recurs.
	 * @pre Disposem d'un token vlid. 		
	 * @post S'ha recuperat el llistat de carpetes del recurs i es mostren al desplegable.
	 */
	 private class LoadMailFolderListTask extends AsyncTask<String, Void, Boolean> {
				
		protected void onPostExecute(Boolean result) {
			Spinner spinner;
			
			if (result == true) {	
				
				// Tanquem finestra de progress
				if (dialog.isShowing()){
					dialog.dismiss();
				}
				
				Log.i("iMESSAGELIST", "S'ha carregat conjunt carpetes");
			
				// TODO - Gestio de Carpetes [ Pendent UOC OPEN API ]
				// Afegir al desplegable el conjunt de carpetes recuperat.
				
				spinner = (Spinner) findViewById(R.id.spinnerMail);
				
				// Afegim el llistat de carpetes al desplegable.
				
				// Les carpetes Rebuts i Sense llegir sempre sn al desplegable.
				List<String> list = new ArrayList<String>();
				list.add("Rebuts");
				list.add("Sense llegir");		
								
				// Afegim la resta de carpetes que hem recuperat.
				Iterator<Folder> itr = folderlist.getFolderList().iterator();
					while(itr.hasNext()) {
						Folder element =  itr.next();
						list.add(Utilities.cutString(20,element.getName()));	     
				}				
				
				ArrayAdapter<String> dataAdapter = new ArrayAdapter<String>( getBaseContext(),  android.R.layout.simple_spinner_item, list);
				dataAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
				spinner.setAdapter(dataAdapter);
					
				
			} else {
				// Tanquem finestra de progress
				if (dialog.isShowing()){
					dialog.dismiss();
				}
				// S'ha produt algun error en la recuperaci de les dades. Ho notifiquem a l'usuari.
				Toast.makeText(getApplicationContext(),
						"No s'han pogut recuperar carpetes", Toast.LENGTH_LONG).show();				
			}
		 }
		
		 @Override
		 protected void onPreExecute() {			
		 	super.onPreExecute();
		 	
		 	// Obrim finestra de progress
		 	dialog.setMessage("Carregant missatges...");
		 	dialog.show();
		 }

		 protected Boolean doInBackground(String... params) {			
				
			if (params[0] == null) return false; 
			
			// Recuperem llistat de carpetes de la bstia/board
			folderlist = FolderList.getFolders(params[0]+"folders", token);	
			
			if (folderlist != null) return true;			
			return false;
		 }
	 }
		
	 /**
	  * Recupera les dades d'una carpeta. Tasca asyncrona. 
	  * 
	  * @param String URI de la carpeta a recuperar,
	  * @pre Disposem d'un token vlid. 		
	  * @post S'han recuperat de dades de la carpeta.
	  */
	 private class LoadMailFolderTask extends AsyncTask<String, Void, Boolean> {		
			
		protected void onPostExecute(Boolean result) {
			TextView label;			
						
			label = (TextView) findViewById(R.id.info_ButtonBustia);
			
			// Tanquem finestra de progress
			if (dialog.isShowing()){
				dialog.dismiss();
			}
			
				if (result == true) {	
					
						Log.i("iMESSAGELIST", "S'ha carregat carpeta");
				
						// modifiquem les etiquetes segons dades de la carpeta recuperada.
						unreadMessages = folder.getUnreadMessages();	
						totalMessages = folder.getTotalMessages();
						
						label = (TextView) findViewById(R.id.aula_messagePendent);
						label.setText(Long.toString(unreadMessages));
						
						label = (TextView) findViewById(R.id.aula_message);
						label.setText(Long.toString(totalMessages));
					
					
				} else {
					// S'ha produt algun error en la recuperaci de les dades. Ho notifiquem a l'usuari.
					Toast.makeText(getApplicationContext(),
							"No s'ha pogut recuperar carpeta", Toast.LENGTH_LONG).show();	
					
					
				}
		}

		@Override
		protected void onPreExecute() {			
			super.onPreExecute();
			
			// Obrim finestra de progress
		 	dialog.setMessage("Carregant missatges...");
		 	dialog.show();
		}

		protected Boolean doInBackground(String... params) {
			
			if (params[0] == null) return false;
					
			//Recuperem carpeta
			folder = Folder.getFolder(params[0], token);
						
			if (folder != null) return true;			
			return false;
		}
	}
		
	
	 /**
     * Recupera un conjunt de missatges d'una carpeta.    
     * Tasca asyncrona. 
	 * 
	 * @param String URI de la carpeta. 
	 * @pre Disposem d'un token vlid. 		
	 * @post S'ha recuperat un conjunt de missatges d'una carpeta i es mostren al llistat.
	 */
	private class LoadMailMessagesTask extends AsyncTask<String, Void, Boolean> {		
		
		protected void onPostExecute(Boolean result) {			
			
			if (result == true) {
				
				list=(ListView)findViewById(R.id.mailList);				
				
				try { 
					// Getting adapter by passing xml data ArrayList
					adapter=new mailAdapter(a, messages);
					list.setAdapter(adapter);
				} catch (Exception ex) {
					Toast.makeText(getApplicationContext(),
							ex.getMessage(), Toast.LENGTH_LONG).show();
				}
					
				
			} else {
				// S'ha produt algun error en la recuperaci de les dades. Ho notifiquem a l'usuari.
				Toast.makeText(getApplicationContext(),
						"No s'ha pogut recuperar Correu", Toast.LENGTH_LONG).show();				
			}
		}

		@Override
		protected void onPreExecute() {			
			super.onPreExecute();
		}

		protected Boolean doInBackground(String... params) {	
			
			// TODO - Carregar noms n missatges amb n=params[1]
				
			messages = MessageList.getMessages(params[0], token);							
			
			if (messages != null) return true;			
			return false;
		}
	}
	
	/**
     * Conjunt de disparadors de la Activity.    
	 */
	
	public void addListenerOnButtons() {	
			
		/**
	     * Bot tancar de la barra de men - Finalitza l'activity.    
		 */
		findViewById(R.id.titleBarButton).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				finish();
			}		 
		});
		
		/**
	     * Bot refresta de la barra al peu - Recarrega l'activity.    
		 */
		findViewById(R.id.footerBarRefresh).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				finish();				
				startActivity(getIntent());
			}		 
		});
		
		/**
	     * Selector de carpeta - Permet seleccionar la carpeta i carregar els missatges relacionats.    
		 */
		Spinner spinner = (Spinner) findViewById(R.id.spinnerMail);
		spinner.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
		    public void onItemSelected(AdapterView<?> parent, View view, int pos, long id) {
		    	String messageURI;
		    	String folderURI;
		    	Folder tmp;
		    	
		    	// TODO - Limitar nombre de missatges a recuperar incialment.
		    	
		    	// Comprova si s'ha recuperat el llistat de carpetes, 
		    	// Si no s'ha recuperat no fer res.
		    	if (folderlist != null) {
		    		
		    		// TODO - UOC OPEN API no retorna missatges al fer crides a la carpeta REBUTS d'un BOARD
		    		//		  Tampoc retorna al fer crida a carpeta SENSE LLEGIR d'un BOARD
		    		//		  Es deixa crida per ID de carpeta, mentren no solventen BUG
		    		
		    		switch (pos) {
		    	    	case 0:  
		    	    	 	// la primera posici del desplegable s la carpeta rebuts
		    				// folderURI = baseURI +"folders/inbox";
		    				// messageURI = baseURI +"messages";
		    	    		
		    	    		tmp = folderlist.getFolderList().get(0);
		    	    		messageURI = baseURI +"folders/"+tmp.getId()+"/messages";
		    	    		folderURI = baseURI +"folders/"+tmp.getId();
		    				 break;
		    	    	case 1:  
		    	    		// la segona posici del desplegable s la carpeta rebuts sense llegir
		    	    		tmp = folderlist.getFolderList().get(1);
		    	    		messageURI = baseURI +"folders/"+tmp.getId()+"/messages";
		    	    		folderURI = baseURI +"folders/"+tmp.getId();
		    	    		
		    	    		// messageURI = baseURI +"messages/unread";
		    	    		// folderURI = baseURI +"folders/inbox";
		    	    		break;		    	    
		    	    	default: 
		    	    		 // la resta de carpetes s'ubiquen a partir de la posici 2
		    	    		 tmp = folderlist.getFolderList().get(pos-2);
		    	    		 messageURI = baseURI +"folders/"+tmp.getId()+"/messages";
		    	    		 folderURI = baseURI +"folders/"+tmp.getId();
		    		}
		    		
		    		// Recuperem el llistat de missatges de la carpeta.
		    		new LoadMailFolderTask().execute( folderURI);
		    		new LoadMailMessagesTask().execute(messageURI);
		    		
		    		Log.i("Position", String.valueOf(pos));
		    		
		    	}
		    }
		    public void onNothingSelected(AdapterView<?> parent) {
		    }
		});
		
		/**
	     * Al prmer sobre un correu obre la finestra per llegir-lo.    
		 */
		ListView list=(ListView)findViewById(R.id.mailList);
		list.setOnItemClickListener(new AdapterView.OnItemClickListener() {
		    public void onItemClick(AdapterView<?> parent, View view, int pos, long id) {
		    	String str = new String();
		    	String context = new String();
		    	TextView label;
		    			    	
		    	// Comprovem si el context s la bstia de correu o b un recurs de conversa
		    	if (baseURI.contentEquals("mail/")){
		    		context = "Bstia -" + folder.getName();
		    		str = baseURI + "messages/"+ messages.getMessageList().get(pos).getId();		    		
		    	} else {		    		
		    		str = baseURI + "folders/"+ folder.getId()+"/messages/"+ messages.getMessageList().get(pos).getId();
		    		context = contxt;
		    	}
		    	
		    	
		    	if ( str != null){
		    		
		    		// Marquem el missatge com ha llegit i modifiquem els contadors.
		    		
		    		// TODO - La UOC OPEN API no marca el correus com a llegits quan es llegeixen.
		    		//		  Aix vol dir que al recarregar el llistat, els missatges tornaran a sortir com a no llegits.
		    		
		    		
		    		
		    		if (messages.getMessageList().get(pos).getStatus() == 0){
		    			
		    			messages.getMessageList().get(pos).setStatus(1);
		    			View vi = view;
		    			ImageView image = (ImageView)vi.findViewById(R.id.listMail_image); 		
		    			image.setVisibility(ImageView.INVISIBLE);
		    			
		    			
		    			if (unreadMessages > 0){
		    				unreadMessages--;
		    			}
		    			label = (TextView) findViewById(R.id.aula_messagePendent);
						label.setText(Long.toString(unreadMessages));   			
		    		}
		    		
		    		Log.i("MessageId", str);
		    		
		    		// Preparem l'Intent per mostrar el missatge i el cridem.
		    		
		    		Intent i = new Intent(InboxActivity.this, MessageActivity.class);		    						
		    		i.putExtra("URI",str);
		    		i.putExtra("context",context);
		    		startActivity(i); 
		    	}
		    }	
		});
	}
	
	
	
	@Override
	protected void onDestroy() {
		super.onDestroy();
		this.list = null;
		this.adapter = null;
		this.folder = null;
		this.folderlist = null;
		this.messages = null;
	}

}
