/**
 *  UOC Hive Campus per UOC OPEN API
 *  <br />
 *  
 *
 *  @author Ral Martnez Daz
 *  @version 1.0
 */

package com.uoc.hive.campus;



import java.util.Iterator;

import com.uoc.hive.campus.model.BoardList;
import com.uoc.hive.campus.model.ClassRoom;
import com.uoc.hive.campus.model.ClassRoomList;

import android.os.AsyncTask;
import android.os.Bundle;
import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.ListView;

import android.widget.TextView;
import android.widget.Toast;

public class ListClassRoomActivity extends Activity {
	
	private String token;
	
	private listClassRoomAdapter adapter;
	
	private ClassRoomList classRooms;
	private Activity a;
	
	private ProgressDialog dialog;
	
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_list_classroom);
		
		a = this;
		
		// Verifiquem que tenim el token
		token = Utilities.getToken(); 
		if (token.contentEquals("error")) {
			finish();
		}
		
		// Modifiquem titol
		TextView label = (TextView) findViewById(R.id.titleBarText);
		label.setText(R.string.title_activity_list_class_room);
		
		// Mostrem barra de progres mentre es carrega el llistat d'aules.
		dialog = new ProgressDialog (a);		
							
		addListenerOnButtons();
		
		Log.i("iCLASSROOMLIST", "S'ha iniciat llistat d'aules");
	}
	
	@Override
	protected void onResume () {
		super.onResume ();
		 
		// Verifiquem que tenim el token
		token = Utilities.getToken(); 
		if (token.contentEquals("error")) {
				finish();
		}		
		// Recuperem llitat d'aules i recursos de conversa.			
		new LoadClassroomListTask().execute();
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.message, menu);
		return true;
	}
	@Override
	public boolean onOptionsItemSelected(MenuItem item){
		switch(item.getItemId()){
			case R.id.menu_close:
				finish();
				return true;
			case R.id.menu_settings:
					Intent i = new Intent(ListClassRoomActivity.this, TaulellActivity.class);
					startActivity(i.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP));
				return true;	
			default:
				return super.onContextItemSelected(item);			
		}
	}
	
	 /**
     * Recupera el llistat d'aules de l'usuari. Tasca asyncrona. 
	 * 	
	 * @pre Disposem d'un token vlid. 		
	 * @post S'ha recuperat el llistat d'aules de l'usuari i es mostra al desplegable.
	 */
	 private class LoadClassroomListTask extends AsyncTask<String, Void, Boolean> {
				
		protected void onPostExecute(Boolean result) {
			ListView list;
			
			// Tanquem finestra de progress
			if (dialog.isShowing()){
				dialog.dismiss();
			}
			
			Log.i("iCLASSROOMLIST", "S'ha carregat llistat d'aules");
			
			if (result == true) {				
						
				list = (ListView) findViewById(R.id.classroomList);				
				try { 
					// Creem el llistat d'aules amb les dades recuperades.
					adapter=new listClassRoomAdapter(a, classRooms);
					list.setAdapter(adapter);
					
				} catch (Exception ex) {
					Toast.makeText(getApplicationContext(),
							ex.getMessage(), Toast.LENGTH_LONG).show();
				}
				
			} else {
				// S'ha produt algun error en la recuperaci de les dades. Ho notifiquem a l'usuari.
				Toast.makeText(getApplicationContext(),
						"No s'han pogut recuperar aules", Toast.LENGTH_LONG).show();				
			}
		 }
		
		 @Override
		 protected void onPreExecute() {			
		 	super.onPreExecute();
		 	
		 	// Obrim finestra de progress
		 	dialog.setMessage("Carregant llistat d'aules...");
		 	dialog.show();
		 }

		 protected Boolean doInBackground(String... params) {			
			BoardList tempBoards;
			 
			// Recuperem llistat de carpetes de la bustia
			classRooms = ClassRoomList.getClassRoomListRequest(token);
			
			if (classRooms != null) {
				// Comprova que l'usuari tingui aules assignades i obt el llistat de recursos de conversa de cada aula.
				Iterator<ClassRoom> itr = classRooms.getAulesList().iterator();
				while(itr.hasNext()) {
					ClassRoom element =  itr.next();	         
					tempBoards = BoardList.getBoardListRequest(element.getId(), token);
					element.setBoards(tempBoards);				    
				}
				return true;
			}			
			return false;
		 }
	 }
	 
	
	/**
     * Conjunt de disparadors de la Activity.    
	 */	
	public void addListenerOnButtons() {	
			
		/**
	     * Bot tancar de la barra de men - Finalitza l'Activity.    
		 */
		findViewById(R.id.titleBarButton).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				finish();
			}		 
		});
		
		/**
	     * Al prmer sobre un correu obre la finestra per llegir-lo.    
		 */
		ListView list=(ListView)findViewById(R.id.classroomList);
		list.setOnItemClickListener(new AdapterView.OnItemClickListener() {
		    public void onItemClick(AdapterView<?> parent, View view, int pos, long id) {
		    	String str = new String();
		    	
		    	str = classRooms.getAulesList().get(pos).getId();
		    	
		    	Log.i("iCLASSROOMLIST", "S'ha cridat l'aula " + str);
		    	
		    	Intent i = new Intent(ListClassRoomActivity.this, ClassRoomActivity.class);
	    		i.putExtra("token",token);			
	    		i.putExtra("URI",str);	    		
	    		startActivity(i); 		    	
		    }
		});
		
		/**
	     * Bot refresca de la barra al peu - Recarrega l'Activity.    
		 */
		findViewById(R.id.footerBarRefresh).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				new LoadClassroomListTask().execute();
			}		 
		});
	}

}
