/**
 *  UOC Hive Campus per UOC OPEN API
 *  <br />
 *  
 *
 *  @author Ral Martnez Daz
 *  @version 1.0
 */

package com.uoc.hive.campus;



import java.text.SimpleDateFormat;
import java.util.Date;

import com.uoc.hive.campus.model.Message;
import com.uoc.hive.campus.model.MessageBody;

import android.os.AsyncTask;
import android.os.Bundle;
import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;

import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

public class MessageActivity extends Activity {	
	private String token, messageURI, context;
	private Message message; 
	private MessageBody messageBody;
	
	private SimpleDateFormat sdf = new SimpleDateFormat("h:mm EEE, d MMM");	
	
	private TextView from, to, subject, date, body;
	private ImageView image;
	
	private ProgressDialog dialog;
	private Activity a;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_message);
		
		// Recuperem el token
		token = Utilities.getToken(); 
		if (token.contentEquals("error")) {
				finish();
		}
		a = this;
		
		// Modifiquem titol
		TextView label = (TextView) findViewById(R.id.titleBarText);
		label.setText(R.string.title_activity_message);
				
		ImageView image = (ImageView) findViewById(R.id.titleBarButton);
		image.setImageResource(R.drawable.ic_close);
		
		// Recuperem 
		Bundle extras = getIntent().getExtras();
		if (extras != null) {			   
			   this.messageURI = extras.getString("URI");			   
			   this.context = extras.getString("context");	
			   
			   TextView titlelabel = (TextView) findViewById(R.id.aulaTitle);
			   titlelabel.setText(Utilities.cutString(35, context));
			   
		} else {
				Toast.makeText(this, "Error de intent", Toast.LENGTH_LONG).show();
				finish();
		}
		
		// Creem barra de progress per mostrar mentre es carrega el llistat d'aules.
		dialog = new ProgressDialog (a);
				
		
		addListenerOnButtons();
	}
	
	@Override
	protected void onResume () {
		super.onResume();
		// Verifiquem que tenim el token
		token = Utilities.getToken(); 
		if (token.contentEquals("error")) {
			finish();
		}
		
		// Carreguem les dades del missatge i el cos del missatge
		new LoadMessageTask().execute(messageURI);
		new LoadMessageBodyTask().execute(messageURI);
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.message, menu);
		return true;
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item){
		switch(item.getItemId()){
			case R.id.menu_close:
				finish();
				return true;
			case R.id.menu_settings:
					Intent i = new Intent(MessageActivity.this, TaulellActivity.class);
					startActivity(i.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP));
				return true;	
			default:
				return super.onContextItemSelected(item);			
		}
	}
	
	/**
     * Recupera un missatge. Tasca asyncrona. 
	 * 
	 * @param String id del missatge.
	 * @pre Disposem d'un token vlid. 		
	 * @post S'ha recuperat el missatge i es mostra..
	 */
	 private class LoadMessageTask extends AsyncTask<String, Void, Boolean> {
		
		
		protected void onPostExecute(Boolean result) {
			Date data;
			
			if (result == true) {
				
				// Tanquem finestra de progress
				if (dialog.isShowing()){
					dialog.dismiss();
				}
			
				from = (TextView) findViewById(R.id.messageFrom);
				to = (TextView) findViewById(R.id.messagePara);	
				subject = (TextView) findViewById(R.id.messageTitle);	
				date= (TextView) findViewById(R.id.messageDate);				
				
				from.setText(message.getFrom());
				to.setText(message.getTo());
				subject.setText(message.getSubject());				
				
				data = Utilities.parseDateTime(message.getDate());	
			    date.setText(sdf.format(data));
			    
			    
		        
		        
				
			} else {
				// S'ha produt algun error en la recuperaci de les dades. Ho notifiquem a l'usuari.
				Toast.makeText(getApplicationContext(),
						"No s'ha pogut recuperar el missatge", Toast.LENGTH_LONG).show();				
			}
		 }
		
		 @Override
		 protected void onPreExecute() {			
		 	super.onPreExecute();
		 	
		 	// Obrim finestra de progress
		 	dialog.setMessage("Carregant missatge...");
		 	dialog.show();
		 }

		 protected Boolean doInBackground(String... params) {			
				
			if (params[0] == null) return false; 
			
			message = Message.getMessage(params[0], token);
			if (message != null) return true;
			
			return false;
		 }
	 }

	 /**
	     * Recupera el cos d'un missatge. Tasca asyncrona. 
		 * 
		 * @param String id del missatge.
		 * @pre Disposem d'un token vlid. 		
		 * @post S'ha recuperat cos del missatge i es mostra
		 */
		 private class LoadMessageBodyTask extends AsyncTask<String, Void, Boolean> {			
			
			protected void onPostExecute(Boolean result) {				
				
				if (result == true) {				
									
					body = (TextView) findViewById(R.id.messageBody);					
					body.setText(messageBody.getBody());
					
				} else {
					// S'ha produt algun error en la recuperaci de les dades. Ho notifiquem a l'usuari.
					Toast.makeText(getApplicationContext(),
							"No s'ha pogut recuperar el cos del missatge", Toast.LENGTH_LONG).show();				
				}
			 }
			
			 @Override
			 protected void onPreExecute() {			
			 	super.onPreExecute();
			 }

			 protected Boolean doInBackground(String... params) {	
				 if (params[0] == null) return false; 
				
				messageBody = MessageBody.getMessageBody(params[0]+"/body", token);
				if (message != null) return true;
				
				return false;
			 }
		 }
	
	
	/**
     * Conjunt de disparadors de la Activity.    
	 */
	
	public void addListenerOnButtons() {	
			
		/**
	     * Bot tancar de la barra de men - Finalitza l'activity.    
		 */
		findViewById(R.id.titleBarButton).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				finish();
			}		 
		});
		
		/**
	     * Bot refresta de la barra al peu - Recarrega l'activity.    
		 */
		findViewById(R.id.footerBarRefresh).setOnClickListener(new OnClickListener() {				 
			@Override
			public void onClick(View arg0) {					
				finish();				
				startActivity(getIntent());
			}		 
		});
	}
}
