/**
 *  UOC Hive Campus per UOC OPEN API
 *  <br />
 *  
 *
 *  @author Ral Martnez Daz
 *  @version 1.0
 */

package com.uoc.hive.campus;

import com.uoc.hive.campus.model.ClassRoomList;

import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.AsyncTask;
import android.os.Bundle;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;

import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

public class TaulellActivity extends Activity {
	
	private String token;
	private appUser appUserData;
	
	private TextView user_name;		
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_taulell);        
       
        user_name = (TextView) findViewById(R.id.user_title_text);    
        
        ImageView image = (ImageView) findViewById(R.id.titleBarButton);
		image.setImageResource(R.drawable.ic_close);	
       
        token = Utilities.getToken();   
                     
        addListenerOnButtons();
    }

   
    @Override
    protected void onResume() {
    	super.onResume();
    	
    	
    	// Si no hi ha connexi a Internet, tanca i torna a Activity de validaci.
    	if (isOnline() == false){
    		Toast.makeText(getApplicationContext(),
					"S'ha perdut connexi a Internet", Toast.LENGTH_LONG).show();
    		
    		Intent i = new Intent(TaulellActivity.this, HiveCampusActivity.class);
			startActivity(i.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP));
    	}
    	
    	// Comprovem que tenim el token de l'usuari.
    	if (!token.equals("")) {        	           
         	
             Log.i("iTAULELL", "Carregant dades de l'usuari... ");
             
         	// Tasca asyncrona. Recuperem les dades de l'usuari.        	
         	new LoadUserTask().execute(token); 
         	
         } else {
         	Toast.makeText(this, "Error de login", Toast.LENGTH_LONG).show();
         } 
    }
    
    /**
     * Comprova si el dispositiu disposa de connexi a Internet
     * @return TRUE - si el dispositiu disposa de connexi a Internet<br>
     *		   FALSE -si no disposem de connexi.
     */
	public boolean isOnline() {
	    ConnectivityManager cm =
	        (ConnectivityManager) getSystemService(Context.CONNECTIVITY_SERVICE);
	    NetworkInfo netInfo = cm.getActiveNetworkInfo();
	    if (netInfo != null && netInfo.isConnected()) {
	        return true;
	    }
	    return false;
	}
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.logon_menu, menu);
        return true;
    }
    
    @Override
	public boolean onOptionsItemSelected(MenuItem item){
		switch(item.getItemId()){
			case R.id.menu_close:
				finish();
				return true;				
			default:
				return super.onContextItemSelected(item);			
		}
	}
    
    public  ClassRoomList getClassRoomsList(){
    	return this.appUserData.getClassRooms();
    }

	
    /**
     * Recupera les dades de l'usuari. Tasca asyncrona. 
	 * 
	 * @pre Disposem d'un token vlid.
	 * @post L'objecte appUserData est inicialitzat i cont les dades de l'usuari que est utilitzant l'aplicaci.
	 */
	private class LoadUserTask extends AsyncTask<String, Void, appUser> {
		protected void onPostExecute(appUser result) {
			if (result != null) {	
				
				appUserData = result;
				
				user_name.setText((CharSequence) appUserData.getUser().getFullName());
				
				Log.i("iTAULELL", "User load ok!");
				// Tasques asyncrones. Recuperen els tutors,les aules, i les dades de la carpeta Rebuts.        	
	            new LoadUserTutorsTask().execute();          
	            new LoadUserClassRoomsTask().execute();
	            new LoadUserInboxTask().execute();
	            
			} else {
				Toast.makeText(getApplicationContext(),
						"Hay problemas de conexin", Toast.LENGTH_LONG).show();
			}
		}

		@Override
		protected void onPreExecute() {			
			super.onPreExecute();
		}

		/**     
		 * @param String... token - El oathtoken de l'usuari-
		 */
		@Override
		protected appUser doInBackground(String... token) {			 
			return new appUser(token[0]);						
		}
	}
	
	 /**
     * Recupera els tutors de l'usuari. Tasca asyncrona. 
	 * 
	 * @pre Disposem d'un token vlid.<br> 
	 * 		appUserData est inicialitzat amb les dades de l'usuari.
	 * @post S'ha incorporat el llista d'aules al perfil de l'usuari
	 */
	private class LoadUserTutorsTask extends AsyncTask<String, Void, Boolean> {
		
		protected void onPostExecute(Boolean result) {
			if (result != true) {
				Toast.makeText(getApplicationContext(),
						"Hay problemas de conexin", Toast.LENGTH_LONG).show();
			} else {
				Log.i("iTAULELL", "User Tutors load ok!");
			}
		}

		@Override
		protected void onPreExecute() {			
			super.onPreExecute();
		}

		protected Boolean doInBackground(String... params) {				
			appUserData.loadUserTutorsData();
			return true;
		}
	}
	
	/**
     * Recupera les aules de l'usuari. Tasca asyncrona. 
	 * 
	 * @pre Disposem d'un token vlid. L'objecte usuari est inicialitzat amb les dades de l'usuari.
	 * @post Incorporem a l'objecte usuari els llistat d'aules de l'usuari. 
	 */
	private class LoadUserClassRoomsTask extends AsyncTask<String, Void, Boolean> {
		
		protected void onPostExecute(Boolean result) {
			String str;
			
			TextView label = (TextView) findViewById(R.id.info_ButtonAules);
			TextView aules = (TextView) findViewById(R.id.ButtonAccesClassroom);
			
			if (result == true) {
				
				Log.i("iTAULELL", "User ClassRooms load ok!");	
				
				// Si hi ha missatges sense llegir a les aules, mostrem detall.
				int i = appUserData.getClassrooms_unread();
				if ( i > 0) {
					str = Integer.toString(i);
					
					label.setText(str);
					label.setVisibility(TextView.VISIBLE);				
				}
				
				// Mostrem bot d'accs rpid a la primera aula.
				str = appUserData.getClassRooms().getAulesList().get(0).getTitle();
				str = Utilities.cutString(25, str);
				aules.setText(str);
				
				aules.setVisibility(TextView.VISIBLE);
				
			} else {	
				Toast.makeText(getApplicationContext(),
						"Hay problemas de conexin", Toast.LENGTH_LONG).show();
				label.setText("!");
				label.setVisibility(TextView.VISIBLE);
			}
		}

		@Override
		protected void onPreExecute() {			
			super.onPreExecute();
		}

		protected Boolean doInBackground(String... params) {				
			appUserData.loadUserClassRoomsData();			
			return true;
		}
	}
	
	 /**
     * Recupera les dades de la bstia Rebuts de l'usuari. Tasca asyncrona. 
	 * 
	 * @pre Disposem d'un token vlid.<br> 
	 * 		appUserData est inicialitzat amb les dades de l'usuari.
	 * @post S'han incorporat les dades de la bstia Rebuts de l'usuari.
	 */
	private class LoadUserInboxTask extends AsyncTask<String, Void, Boolean> {
		
		@SuppressWarnings("static-access")
		protected void onPostExecute(Boolean result) {
			TextView label;
			String s;
			
			Log.i("iTAULELL", "User inbox load ok!");
					
			label = (TextView) findViewById(R.id.info_ButtonBustia);
			
			if (result == true) {	
				
				// Comprovem si hi ha correus sense llegir a la bstia Rebuts
				Long l = appUserData.getInbox().getUnreadMessages();				
				
				if ( l > 0) {
					s = Long.toString(l);
					
					label.setText(s);
					label.setVisibility(label.VISIBLE);
				}
				
			} else {
				// S'ha produt algun error en la recuperaci de les dades. Ho notifiquem a l'usuari.
				Toast.makeText(getApplicationContext(),
						"No s'ha pogut recuperar Correu", Toast.LENGTH_LONG).show();
				label.setText("!");
				label.setVisibility(label.VISIBLE);
			}
		}

		@Override
		protected void onPreExecute() {			
			super.onPreExecute();
		}

		protected Boolean doInBackground(String... params) {			
				
			if (appUserData.loadUserInboxData() == true) return true;		
			
			return false;
		}
	}
	
	
	/**
     * Conjunt de disparadors de la Activity.    
	 */
	public void addListenerOnButtons() {		
		
			/**
			 * 	Bot aules - dona accs a llistat d'aules   
			*/
			findViewById(R.id.ButtonAules).setOnClickListener(new OnClickListener() {
 
				@Override
				public void onClick(View arg0) {					
					Intent i = new Intent(TaulellActivity.this, ListClassRoomActivity.class);					
					startActivity(i); 
				}		 
			});
			
			/**
			* 	Bot bstia - dona accs a la bstia   
			*/
			findViewById(R.id.ButtonBustia).setOnClickListener(new OnClickListener() {
				 
				@Override
				public void onClick(View arg0) {					
					Intent i = new Intent(TaulellActivity.this, InboxActivity.class);					
					i.putExtra("URI","mail/");
					startActivity(i); 
				}		 
			});
			
			/**
			* 	Bot calendari - Obre el calendari    
			*/			
			findViewById(R.id.ButtonCalendari).setOnClickListener(new OnClickListener() {				 
				@Override
				public void onClick(View arg0) {					
					Intent i = new Intent(TaulellActivity.this, CalendarActivity.class);
					startActivity(i);
				}		 
			});
			
			/**
			* 	Bot tancar de la barra de men - Finalitza l'activity.    
			*/			
			findViewById(R.id.titleBarButton).setOnClickListener(new OnClickListener() {				 
				@Override
				public void onClick(View arg0) {					
					finish();
				}		 
			});
			
			/**
			* 	Bot accs rpid a aula - Llena Activity aula.    
			*/			
			findViewById(R.id.ButtonAccesClassroom).setOnClickListener(new OnClickListener() {				 
				@Override
				public void onClick(View arg0) {					
					String str = new String();
			    	
					str = appUserData.getClassRooms().getAulesList().get(0).getId();
			    	
			    	Log.i("iCLASSROOMLIST", "S'ha cridat l'aula " + str);
			    	
			    	Intent i = new Intent(TaulellActivity.this, ClassRoomActivity.class);
		    		i.putExtra("token",token);			
		    		i.putExtra("URI",str);	    		
		    		startActivity(i); 
				}		 
			});
			
			
	}
	
	
}
