/**
 *  UOC Hive Campus per UOC OPEN API
 *  <br />
 *  
 *
 *  @author Ral Martnez Daz
 *  @version 1.0
 */
package com.uoc.hive.campus;


import java.util.Iterator;


import com.uoc.hive.campus.model.Board;
import com.uoc.hive.campus.model.BoardList;
import com.uoc.hive.campus.model.ClassRoom;
import com.uoc.hive.campus.model.ClassRoomList;
import com.uoc.hive.campus.model.Folder;
import com.uoc.hive.campus.model.User;
import com.uoc.hive.campus.model.UserList;



/**
 * Representa un usuari de l'aplicaci. <br />
 * Permet recuperar del Campus Virtual les dades de l'usuari, el llistat de tutors, el llistat
 * d' aules on est matriculat, els missatges de la bstia i el calendari. <br /><br />
 *
 * @pre	L'usuari s'ha identificat i hem obtingut un token vlid.
 */
public class appUser  {

	private User user;
	private UserList tutors;
	private Folder inbox;
	private ClassRoomList classRooms;
	
	private int classrooms_unread;
	
	private String oathtoken;
	
	
	/**
	 * Constructor. Donat un token vlid obt les dades de l'usuari.	 
	 */
	public appUser(String oathtoken) {	
		
		this.setOathToken(oathtoken);
		
		// Obtenim les dades de l'usuari que utilitza l'aplicaci
		this.user = this.getUserRequest(oathtoken);					
	}
	
	
	/**
	 * Obt el llistat de tutors de l'usuari.
	 * @return el llistat de tutors de l'usuari.	 
	 */
	public UserList getTutors() {		
		return tutors;
	}
	
	/**
	 * Obt l'usuari de l'aplicaci.
	 * @return l'usuari de l'aplicaci.	 
	 */
	public User getUser() {		
		return user;
	}
	
	/**
	 * Obt el llistat d'aules de l'usuari.
	 * @return el llistat d'aules de l'usuari
	 */
	public ClassRoomList getClassRooms() {		
		return classRooms;
	}
	
	/**
	 * Obt la carpeta Rebuts (Inbox) de l'usuari.
	 * @return les dades de la carpeta Rebuts de l'usuari.
	 */
	public Folder getInbox() {		
		return inbox;
	}

	/**
	 * Retorna el nombre de missatges no llegits a les aules
	 * @return  el nombre de missatges no llegits en el conjunt de les aules.
	 */
	public int getClassrooms_unread() {
		return classrooms_unread;
	}

	/**
	 * Recupera del Campus el llistat de tutors de l'usuari.
	 * @return True - Les dades s'han recuperat correctament. </br>
	 * 		   False - S'ha produt algun error durant la recuperaci de les dades.
	 */
	public boolean loadUserTutorsData () {
		UserList temp;
		
		// Obtenim els tutors de l'usuari.		
		temp = this.getTutorsRequest(this.oathtoken);
		
		if (temp !=null) {
			this.tutors = temp;
			return true;			
		}
		return false;
	}
	
	/**
	 * Recupera del Campus el llistat d'aules de l'usuari, aix com els recursos de conversa de 
	 * cada una de les aules. <br />
	 * Contabilitza els missatges no llegits als diferents recursos de conversa de cada aula.
	 * 
	 * @return True - Les dades s'han recuperat correctament. </br>
	 * 		   False - S'ha produt algun error durant la recuperaci de les dades. 
	 */
	public boolean loadUserClassRoomsData () {	
		
		ClassRoomList temp;
		
		// Obtenim les aules de l'usuari		
		temp = this.getAulesRequest(this.oathtoken);
		if (temp != null) {
			this.classRooms = temp;
		
			classrooms_unread = 0;
			
			// Comprova que l'usuari tingui aules assignades i obt el llistat de recursos de conversa de cada aula.
						
			Iterator<ClassRoom> itr = classRooms.getAulesList().iterator();
			while(itr.hasNext()) {
				ClassRoom element =  itr.next();	         
				BoardList recursos =  BoardList.getBoardListRequest( element.getId(), this.oathtoken);
				element.setBoards(recursos);	
				
				// Comprova els elements no llegits de cada board
				Iterator<Board> board_itr = recursos.getBoardList().iterator();
				while(board_itr.hasNext()) {
					Board element_board =  board_itr.next();
					classrooms_unread +=element_board.getUnreadMessages();	
				}
			}
			return true;
		}	
		return false;
	 }
	
	/**
	 * Recupera del Campus les dades de la carpeta Rebuts de l'usuari.
	 * @return True - Les dades s'han recuperat correctament. </br>
	 * 		   False - S'ha produt algun error durant la recuperaci de les dades. 
	 */
	public boolean loadUserInboxData () {
		Folder temp;
		// Obtenim les dades de la carpeta rebuts de l'usuari.
		temp = this.getInboxFolderRequest(this.oathtoken);		
		
		if (temp != null){
			this.inbox = temp;
			return true;		
		}
		return false;
	}
	
		
	/**
	 * Actualitza els diferents recursos de l'usuari, tornant a recuperar les dades des del
	 * Campus Virtual. 
	 */
	public void update () {
		this.loadUserTutorsData();
		this.loadUserInboxData();	
		this.loadUserClassRoomsData();		
	}
	
	
	/**
	 * Recupera les dades de l'usuari.
	 * @return un objecte User amb les dades de l'usuari.
	 */
	private User getUserRequest(String oathtoken){	
		return User.getUser(oathtoken);		
	}
	
	/**
	 * Recupera  el llistat de tutors de l'usuari.
	 * @return un objecte UserList amb els tutors de l'usuari.
	 */
	private UserList getTutorsRequest(String oathtoken){	
		return  UserList.getUserTutorsRequest(oathtoken);
	}

	/**
	 * Recupera les dades de la carpeta Rebuts.
	 * @return un objecte Folder amb les dades de la carpeta Rebuts.
	 */
	private Folder getInboxFolderRequest(String oathtoken){			
		return Folder.getFolder(Constants.MAIL_FOLDER,oathtoken);
	}

	/**
	 * Recupera el llistat d'aules de l'usuari.
	 * @return un objecte ClassRoomList amb les aules de l'usuari.
	 */
	private ClassRoomList getAulesRequest(String oathtoken){	
		return  ClassRoomList.getClassRoomListRequest(oathtoken);
	}
	
	
	/**
	 * Retorna el token OAth de l'usuari.
	 * @return el token OAth de l'usuari.
	 */
	public String getOathToken() {
		return oathtoken;
	}

	/**
	 * Actualitza el token  OAth de l'usuari.
	 * @param oathtoken - el token OAth de l'usuari.
	 */
	public void setOathToken(String oathtoken) {
		this.oathtoken = oathtoken;
	}

}
