/**
 *  Java Model per UOC OPEN API
 *  <br />
 *  Proveeix les classes necessries per a l'implementaci del model de dades
 *	de la UOC OPEN API. Permet des-serialitzar les estructures JSON en objectes
 *	del model de dades.
 *
 *  @author Ral Martnez Daz
 *  @version 1.1
 */
package com.uoc.hive.campus.model;

import com.google.gson.Gson;

/**
 * Representa un Recurs de Conversa dins d'un aula. 
 * <br />
 * Permet des-serialitzar una estructura JSON en l'objecte Board corresponent
 * 
 * @author Ral Martnez Daz
 * @version 1.1
 */

//TODO - Implementar mtodes per a serialitzar un objecte Board en una estructura JSON.

public class Board {	

	private String id;				// Indentificador del recurs de conversa
	private String subtype;			// Subtipus de recurs de conversa
	private String title;			// Ttol del recurs de conversa
	private String code;			// Codi del recurs de conversa. Usat per formar la URL del recurs
	private String domainId;		// Identificador de l'aula que cont aquest recurs de conversa
	private int unreadMessages;	    // Nombre de missatge per llegir
	private int totalMessages;	    // Nombre total de missatges
	
	/**
	 * Constructor
	 */	
	public Board() {
		//Default constructor
	}
	
	/**
	 *  Retorna l'identificador del recurs de conversa.
	 *  @return String amb l'identificador de conversa.
	 */	
	public String getId() {
		return id;
	}	
	/**
	 *  Modifica l'identificador del recurs de conversa.
	 *  @param id - Cadena amb l'identificador del recurs de conversa.
	 */		
	public void setId(String id) {
		this.id = id;
	}
	
	/**
	 *  Retorna el subtipus del recurs de conversa.
	 *  @return String amb el subtipus del recurs de conversa.
	 */	
	public String getSubtype() {
		return subtype;
	}
	/**
	 *  Modifica el subtipus del recurs de conversa.
	 *  @param subtype - Cadena amb el subtipus del recurs de conversa.
	 */	
	public void setSubtype(String subtype) {
		this.subtype = subtype;
	}
	
	/**
	 *  Retorna el ttol del recurs de conversa.
	 *  @return String amb el ttol del recurs de conversa.
	 */	
	public String getTitle() {
		return title;
	}
	/**
	 *  Modifica el ttol del recurs de conversa.
	 *  @param title - Cadena amb el ttol del recurs de conversa.
	 */	
	public void setTitle(String title) {
		this.title = title;
	}
	
	/**
	 *  Retorna el codi del recurs de conversa.
	 *  @return String amb el codi del recurs de conversa.
	 */	
	public String getCode() {
		return code;
	}
	/**
	 *  Modifica el codi del recurs de conversa.
	 *  @param code - Cadena amb el codi del recurs de conversa.
	 */	
	public void setCode(String code) {
		this.code = code;
	}
	
	/**
	 *  Retorna l'identificador de l'aula que cont aquest recurs de conversa.
	 *  @return String amb l'identificador de l'aula que cont aquest recurs de conversa.
	 */	
	public String getDomainId() {
		return domainId;
	}
	/**
	 *  Modifica l'identificador de l'aula que cont aquest recurs de conversa.
	 *  @param domainId - Cadena amb l'identificador de l'aula que cont aquest recurs de conversa.
	 */
	public void setDomainId(String domainId) {
		this.domainId = domainId;
	}
	
	/**
	 * Retorna el nombre de missatges per llegir.
	 * @return int amb el nombre de missatges per llegir.
	 */
	public int getUnreadMessages() {
		return unreadMessages;
	}
	/**
	 * Modifica el nombre de missatges per llegir.
	 * @param unreadMessages - int amb el nombre de missatges per llegir.
	 */
	public void setUnreadMessages(int unreadMessages) {
		this.unreadMessages = unreadMessages;
	}
	
	/**
	 * Retorna el nombre total de missatges del recurs.
	 * @return int amb el nombre total de missatges del recurs.
	 */
	public int getTotalMessages() {
		return totalMessages;
	}
	
	/**
	 * Modifica el nombre total de missatges del recurs. 	 
	 * @param totalMessages - int amb el nombre total de missatges del recurs.
	 */
	public void setTotalMessages(int totalMessages) {
		this.totalMessages = totalMessages;
	}
	
	/**
	 * Des-serialitza una estructura JSON en l'objecte Board corresponent.
	 * @param boardJSON - Una estructura JSON que cont un objecte Board serialitzat.
	 * @return Objecte Board amb les dades de l'estructura JSON des-serialitzada.
	 */
	public static Board JSONToBoard(String boardJSON) {
		return new Gson().fromJson(boardJSON, Board.class);		
	}
	

}

