/**
 *  Java Model per UOC OPEN API
 *  <br />
 *  Proveeix les classes necessries per a l'implementaci del model de dades
 *	de la UOC OPEN API. Permet des-serialitzar les estructures JSON en objectes
 *	del model de dades.
 *
 *  @author Ral Martnez Daz
 *  @version 1.0
 */

package com.uoc.hive.campus.model;

import java.util.ArrayList;

import android.util.Log;

import com.google.gson.Gson;
import com.uoc.hive.campus.RESTClientConnection;

/**
* Representa un llistat de Recuros de Conversa dins d'un aula. 
* <br />
* Permet des-serialitzar una estructura JSON en el llistat d'objectes Board corresponents.
* 
* @author Ral Martnez Daz
* @version 1.1
*/

//TODO - Implementar mtodes per a serialitzar un objecte BoardList en una estructura JSON.

public class BoardList {

private ArrayList<Board> boards;
	
	/**
	 * Constructor
	 */
	public BoardList() {
		//Default constructor
	}

	
	/**
	 * Retorna el llistat de recursos de conversa d'un aula.
	 * @return Un llistat d'objectes Board
	 */
	public ArrayList<Board> getBoardList() {
		return boards;
	}

	/**
	 * Modifica el llistat de recursos de conversa d'un aula.
	 * @return boardsList - Un llistat d'objectes Board
	 */
	public void setBoardList(ArrayList<Board> boardsList) {
		this.boards = boardsList;
	}
	
	/**
	 * Recupera el llistat de recursos de conversa d'un aula.
	 * @param ouathtoken - Un token d'usuari vlid.
	 * @param id - identificador de l'assignatura
	 * @return un objecte BoardList amb el llistat de recursos
	 */
	public static BoardList getBoardListRequest(String id, String ouathtoken) {	
		String requestUri = Constants.BASEURI + "subjects/"+ id +"/boards" ;
		String jsonString =  RESTClientConnection.Get( requestUri , ouathtoken);
		
		if (jsonString != null){
			Log.i("mBoardList", jsonString);
			return JSONtoBoardList(jsonString);
		}
		return null;
	}
	
	/**
	 * Recupera el llistat de recursos de conversa d'un aula en format JSON
	 * @return una cadena JSON amb el llistat de recursos de conversa
	 */
	public static String getJSONBoardListRequest(String ouathtoken) {	
		String requestUri = Constants.BASEURI + "subjects";
		
		String jsonString =  RESTClientConnection.Get( requestUri , ouathtoken);			
		return jsonString;
	}

	/**
	 * Des-serialitza una estructura JSON en un objecte BoardList.
	 * @param jsonString La cadena JSON.
	 * @return un objecte BoardList amb els objectes Board des-serialitzats.
	 */
	private static BoardList JSONtoBoardList(String jsonString) {
		return new Gson().fromJson(jsonString, BoardList.class);
	}


}