/**
 *  Java Model per UOC OPEN API
 *  <br />
 *  Proveeix les classes necessries per a l'implementaci del model de dades
 *	de la UOC OPEN API. Permet des-serialitzar les estructures JSON en objectes
 *	del model de dades.
 *
 *  @author Ral Martnez Daz
 *  @version 1.0
 */
package com.uoc.hive.campus.model;



import android.util.Log;

import com.google.gson.Gson;
import com.uoc.hive.campus.RESTClientConnection;

/**
* Representa un aula. 
* <br />
* Permet des-serialitzar una estructura JSON en l'objecte ClassRoom corresponent.
* 
* @author Ral Martnez Daz
* @version 1.1
*/

// TODO - Implementar mtodes per a serialitzar un objecte ClassRoom en una estructura JSON.

public class ClassRoom {

	private String id;
	private String title;
	private String color;
	private String fatherId;
	private String[] assignments;
	
	private BoardList boards;
	
	final static String URI =  Constants.BASEURI + "classrooms/";
	
	/**
	 *  Constructor
	 */
	public ClassRoom() {
		//Default constructor
	}	
			
	/**
	 *  Method Setters and Getters
	 */
	public String getId() {
		return id;
	}

	
	public void setId(String id) {
		this.id = id;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getColor() {
		return color;
	}

	public void setColor(String color) {
		this.color = color;
	}

	public String getFatherId() {
		return fatherId;
	}

	public void setFatherId(String fatherId) {
		this.fatherId = fatherId;
	}

	public String[] getAssignments() {
		return assignments;
	}

	public void setAssignments(String[] assignments) {
		this.assignments = assignments;
	}

	/**
	 * @return the boards
	 */
	public BoardList getBoards() {
		return boards;
	}

	/**
	 * @param boards the boards to set
	 */
	public void setBoards(BoardList boards) {
		this.boards = boards;
	}
	
	/**
	 * Recupera les dades d'un aula
	 * @return una objecte ClassRoom amb les dades de l'aula.
	 */
	public static ClassRoom getClassRoom(String id, String oathtoken) {
		String requestUri  = URI  + id;	
		String jsonString = RESTClientConnection.Get( requestUri , oathtoken);
		
		if (jsonString != null){
			Log.i("mClassRoom", jsonString);
			return  JSONToClassRoom(jsonString);
		}
		return null;		
	}
	
	/**
	 * Recupera una estructura JSON amb les dade de l'aula.
	 * @return una cadena JSON amb les dades d'un aula
	 */
	public static String getClassRoomRequest(String id, String oathtoken) {
		String requestUri  = URI + id;		
		return RESTClientConnection.Get( requestUri , oathtoken);
	}

	/**
	 * Recupera els recursos de conversa d'un aula.
	 * @param id - identificador de l'aula
	 * @return un objecte BoardList amb els objectes Board des-serialitzats.
	 */
	public static BoardList getClassRoomBoardsRequest(String id, String oathtoken) {		
		return  BoardList.getBoardListRequest(id, oathtoken);		
	}
	
	/**
	 * Des-serialitza un cadena JSON en un objecte ClassRoom.
	 * @param jsonString - Una estructura JSON que cont un objecte ClassRoom serialitzat.
	 * @return un objecte ClassRoom amb les dades de l'aula.
	 */
	public static ClassRoom JSONToClassRoom(String jsonString) {		
		return new Gson().fromJson(jsonString, ClassRoom.class);
		
	}

}
