/**
 *  Java Model per UOC OPEN API
 *  <br />
 *  Proveeix les classes necessries per a l'implementaci del model de dades
 *	de la UOC OPEN API. Permet des-serialitzar les estructures JSON en objectes
 *	del model de dades.
 *
 *  @author Ral Martnez Daz
 *  @version 1.1
 */
package com.uoc.hive.campus.model;

import java.util.ArrayList;

import android.util.Log;

import com.google.gson.Gson;
import com.uoc.hive.campus.RESTClientConnection;

/**
* Representa un llistat d'aules. 
* <br />
* Permet des-serialitzar una estructura JSON en l'objecte ClassRoomList corresponent.
* 
* @author Ral Martnez Daz
* @version 1.1
*/

// TODO - Implementar mtodes per a serialitzar un objecte ClassRoomList en una estructura JSON.

public class ClassRoomList {

	private ArrayList<ClassRoom> classrooms;
	
	/**
	 *  Constructor
	 */
	public ClassRoomList() {
		// Default constructor
	}
	
	/**
	 * Obt el llistat d'aules.
	 * @return un llistat d'objectes ClassRoom.
	 */
	public ArrayList<ClassRoom> getAulesList() {
		return classrooms;
	}
	
	/**
	 * Modifica el llistat d'aules.
	 * @return aulesList - el llistat d'objectes ClassRoom.
	 */
	public void setAulesList(ArrayList<ClassRoom> aulesList) {
		this.classrooms = aulesList;
	}
	
	/**
	 * Recupera el llistat d'aules d'un usuari
	 * @param ouathtoken -  Un token d'usuari vlid.
	 * @return un objecte ClassRoomList amb les aules de l'usuari.
	 */
	public static ClassRoomList getClassRoomListRequest(String ouathtoken) {	
		String requestUri = Constants.BASEURI + "classrooms";
		String jsonString =  RESTClientConnection.Get( requestUri , ouathtoken);	
		
		if (jsonString != null){
			Log.i("mClassRoomList", jsonString);
			return JSONtoClassRoomList(jsonString);
		}
		return null;		
	}
	
	/**
	 * Recupera una estructura JSON que cont el llistat d'aules d'un usuari. 
	 * @return una cadena JSON amb el llistat d'aules.
	 */
	public static String getJSONClassRoomListRequest(String ouathtoken) {	
		String requestUri = Constants.BASEURI + "classrooms";
		return  RESTClientConnection.Get( requestUri , ouathtoken);		
	}

	/**
	 * Des-serialitza un cadena JSON en un objecte ClassRoomList.
	 * @param jsonString - Un estructura JSON que cont un objecte ClassRoomList serialitzat.
	 * @return un objecte ClassRoomList que cont el conjunt d'objecte ClassRoom.
	 */
	private static ClassRoomList JSONtoClassRoomList(String jsonString) {
		return new Gson().fromJson(jsonString, ClassRoomList.class);
	}

}