package com.uoc.hive.campus.model;


import java.util.Date;

import android.util.Log;

import com.google.gson.Gson;
import com.uoc.hive.campus.RESTClientConnection;

public class Event {
	private String id; 				// Identificador de levent
	private String url;				// URL de levent
	private String summary;			// Sumari de l'event
	private long start;			// Data d'inici
	private long  end;				// Data de finalitzaci
		
	final static String URI =  Constants.BASEURI + "calendar/events/";
	
	public Event(){
		//Default constructor
	}
	
	/**
	 * @return the id
	 */
	public String getId() {
		return id;
	}

	/**
	 * @param id the id to set
	 */
	public void setId(String id) {
		this.id = id;
	}

	/**
	 * @return the url
	 */
	public String getUrl() {
		return url;
	}

	/**
	 * @param url the url to set
	 */
	public void setUrl(String url) {
		this.url = url;
	}
/**
	 * @return the summary
	 */
	public String getSummary() {
		return summary;
	}
	
	/**
	 * @param summary the summary to set
	 */
	public void setSummary(String summary) {
		this.summary = summary;
	}

	/**
	 * @return the start
	 */
	public Long getStart() {
		return start;
	}

	/**
	 * @param start the start to set
	 */
	public void setStart(Long start) {
		this.start = start;
	}

	/**
	 * @return the end
	 */
	public Long getEnd() {
		return end;
	}

	/**
	 * @param end the end to set
	 */
	public void setEnd(Long end) {
		this.end = end;
	}

	/**
	 * Recupera les dades d'un event del Campus Virtual.
	 * @param String id - l'identificador de l'event.
	 * @param String token - un token d'usuari vlid.
	 * @return una objecte Event amb les dades de l'event.
	 */
	public static Event getEvent (String id, String oathtoken) {
		String jsonString = getJSONEventRequest (id ,oathtoken);
				
		if (jsonString != null) {
			Log.i("iEvent", jsonString);
			return JSONToEvent(jsonString);
		}
		return null;
	}
	
	/**
	 * Recupera les dades d'un event del Campus Virtual.
	 * @param String id - l'identificador de l'event.
	 * @param String token - un token d'usuari vlid.
	 * @return una cadena JSON amb les dades de l'event.
	 */
	public static String getJSONEventRequest(String id, String token) {
		return RESTClientConnection.Get( URI , token);
	}
	
	/**
	 * Des-serialitza un cadena JSON en un objecte Event.
	 * @param jsonString La cadena JSON.
	 * @return un objecte Event.
	 */
	public static Event JSONToEvent(String jsonString) {		
		return  new Gson().fromJson(jsonString, Event.class);		
	}
}
